#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>

#include "GraphicsCom.c"
#include "Graf.h"
#include "grafprot.h"

/* This subroutine is the same as curve1, except that there is no
   clipping.

   This subroutine traces a curve, or fills an enclosed area,
   providing more control over the details than does subroutine curve.
   The extra control is specified by the five extra switches, init,
   final, closed, draw and fill.

   As in subroutine DrawCurve, the array cpp contains the points
   through which the curve is to pass, and npts is the number of
   elements in the arrays (i.e., the number of points).  However, a
   single call to subroutine DrawCurve2 only specifies a segment of a
   curve; the whole curve can consist of one or more segments.

   The purpose of allowing different segments is to allow different
   parameters with each segment.  The same effect could be achieved
   with repeated calls to subroutine DrawCurve, except for two things:
   One is that DrawCurve2 allows a curve to be closed, so that there
   is proper line joining between the beginning and ending of the
   curve; and the other is that DrawCurve2 allows a region enclosed by
   a curve to be filled with some gray value.

   The parameters which can be specified with each segment are the
   dashing and the bezier or smoothing option.  The linewidth and
   other parameters cannot be set separately for the different
   segments; all segments will share the same value of these
   parameters.

   The switch init should be set for the first segment, and switch
   final should be set for the final segment.  If the segment is the
   final one, and if closed is set, then the curve is closed with a
   closepath command, giving proper joining of initial and final
   segments.  If the draw switch is set, then the curve is drawn.  If
   the fill is set, then the curve is filled with the current gray
   value, as set by subroutine SetGray.

   A call to subroutine DrawCurve is equivalent to the following call
   to subroutine DrawCurve2:

    DrawCurve2(cpp,npts,True,True,False,True,False);  */

void DrawCurve2(CurvePoint *cpp,long npts,
   Bool init,Bool final,Bool closed,Bool draw,Bool fill)
{
  int nq,nr,i,j;

  if(npts<=0)return;

  /* Handle the first point.  If initial segment, start new path
     and moveto 1st point.  If continuing segment, do lineto first
     point, in case first point of this segment not same as last 
     point of previous segment.  */

  if(init){
    fprintf(G.psfile,"newpath %d %d moveto\n",
	    UserxToPix(cpp->x),UseryToPix(cpp->y));
  }
  else{
    fprintf(G.psfile,"%d %d lineto\n",
	    UserxToPix(cpp->x),UseryToPix(cpp->y));
  }

  ++cpp;           /* Done with 1st pt */
  --npts;

  if(npts==0)return;

  /* If beziersw set, generate blocks of three, curveto commands.  Any
     line segments left over must be generated with lineto commands.
     But if beziersw not set, generate whole thing with lineto
     commands.*/

  if(G.beziersw){
    nq=npts/3;
    nr=npts-3*nq;
    
    for(i=0;i<nq;++i){
      for(j=0;j<3;++j){
	fprintf(G.psfile,"%d %d ",UserxToPix(cpp->x),UseryToPix(cpp->y));
	++cpp;
      }
      fprintf(G.psfile," curveto\n");
    }
  }
  else{
    nr=npts;
  }
  
  /* Generate remaining lineto's */    

  for(i=0;i<nr;++i){
    fprintf(G.psfile,"%d %d lineto\n",UserxToPix(cpp->x),UseryToPix(cpp->y));
    ++cpp;
  }
  
  if(final){
    if(closed)fprintf(G.psfile,"closepath\n");
    if(draw){
      if(fill){
	fprintf(G.psfile,"%5.2f setgray gsave fill "
                         "grestore 0 setgray stroke\n",G.gray);
      }
      else fprintf(G.psfile,"stroke\n");
    }
    else if(fill){
      fprintf(G.psfile,"%5.2f setgray fill 0 setgray\n",G.gray);
    }
  }
}
  
      


