/* Set Graphics Common up as a structure to avoid name collisions. */
/* Fortran heritage shows here */

#ifndef BOOLDEF
#define BOOLDEF
typedef int Bool;
enum{False,True};
#endif

#define MAX_LEN_GRAPH_FILENAME  50
#define SIZE_TO_FID             1.0e-4

struct G{
  char      gfnam[MAX_LEN_GRAPH_FILENAME+1];    /* Graphics file name */
                                                /* Default is graf.ps */
  double    conv;         /* Number of page pixels per inch.  A page pixel */
                          /* is arbitrarily defined as 1/300 inch.  */
  double    xwind;        /* xwind,ywind are coordinates of LL corner of */
  double    ywind;        /* graphics window on page, relative to LL */
                          /* of page, measured in inches. */
  double    dxwind;       /* dxwind, dywind are size of graphic window */
  double    dywind;       /* in inches */
  double    xuser;        /* Linear scale:  xuser=user x coordinate of */
  double    yuser;        /* left of graphics window, yuser=user y coord */
                          /* of top of window.  Log scale: */
                          /* xuser=log10(x of left of window), sim yuser.*/
  double    dxuser;       /* Linear scale: dxuser=width of graphics window */
  double    dyuser;       /* in user coords, sim dyuser=height.  Log scale: */
			  /* dxuser=window width in log units, sim dyuser */
                          /* Note that dxuser,dyuser can be negative. */
  int       linwid;       /* Line width in page pixels */
  int       linecap;      /* Line cap paramter, 0,1,2.  */
  int       linejoin;     /* Line join parameter, 0,1,2 */
  int       ixlinlog;     /* linlog switch=0 for linear coords, 1 for log */
  int       iylinlog;
  int       ifontsz;      /* Size of current font */
  int       ncopies;      /* Number of copies desired */
  double    xfid;         /* Coordinates of the origin of fiducial coord */
  double    yfid;         /* Syst, measured in inches rel to LL of page */
  double    fidconvi;     /* Converts fid units to inches; same as length */
                          /* of side of fid square in inches */
  double    fidconvp;     /* Converts fid units to page pixels */
  double    frmfnt;       /* Scale factor, defaulting to 1.0, used to adjust */
                          /* the size of fonts in the frame subroutine.  */
  int       icurfnt;      /* Code (0-12) for current font.  Initialized to */
                          /* -1, means no font set yet. */
  Bool      ispcsw;       /* Set to 0 for normal page output, and to 1 */
                          /* to create graphics files to insert into TeX */
                          /* documents vial the \special command. */
  double    spcscale;     /* Scale factor to (usually) reduce the size */
                          /* of a plot for insertion in a TeX file.  Has */
                          /* an effect on the line width */
  int       landscap;     /* Switch set to 1 for landscape orientation, 0 */
                          /* for normal orientation */
  double    gray;         /* Gray value, 0.0=black, 1.0=white */
  Bool      beziersw;     /* When set, use bezier splines for curves */
  Bool      cntrflsw;     /* Switch set to write contour curves to a file */
  Bool      cntrplsw;     /* Switch set to generate contour curves */
  int       pagecnt;      /* Physical page count */
  FILE      *psfile;      /* Postscript file for output */
};

#ifdef OPEN_GRAPHICS

struct G G={
"graf.ps"                 /* Graphic file name */
};

#else
extern    struct G G;
#endif

#define MIN(x,y) ((x)<(y)?(x):(y))
#define MAX(x,y) ((x)>(y)?(x):(y))



