#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>

#include "GraphicsCom.c"
#include "Graf.h"
#include "grafprot.h"


/* This subroutine defines the fiducial coordinate system in terms of
 inches on the page.  (xc,yc) are the coordinates, in inches, of the
 lower left corner of the fiducial square, which is also the origin of
 the fiducial coordinate system.  The inches are measured relative to
 the lower left corner of the page (which may be turned sideways by
 the call to the newpage subroutine).  The parameter side is the
 length in inches of the side of the fiducial square.

 The convention is that the fiducial square is one fiducial unit on a
 side, so this subroutine serves to completely define the translation
 from fiducial coordinates to absolute position on the page in inches.
 Fiducial coordinates are always given as real numbers.  If you want,
 you can use fiducial coordinates which are outside the fiducial
 square (e.g., negative).

 The purpose of the fiducial coordinate system is to have one system
 of coordinates to which everything else (almost) is tied, so that
 simply by changing the call to this one subroutine, the position and
 scale of the plot can be modified.  This is often very useful. */

void SetFiducial(double xc,double yc,double side)
{    
  /* If special command is given, effectively ignore shift in origin
     of fiducial coordinates. */

  if(G.ispcsw){
    G.xfid=0.0;
    G.yfid=0.0;
  }
  else{
    G.xfid=xc;
    G.yfid=yc;
  }

  /* fidconvi converts fiducial units to inches, and fidconvp converts
     them to pixel units. */

  G.fidconvi=side;
  G.fidconvp=G.fidconvi*G.conv;
}
