#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>

#include "GraphicsCom.c"
#include "Graf.h"
#include "grafprot.h"

/* This function sets a Laser Writer font.  The code indicates the type
   of font, in range 0-12, as follows:

   0.  Times-Roman           1. Times-Bold            2. Times-Italic
   3.  Times-BoldItalic      4. Helvetica             5. Helvetica-Bold
   6.  Helvetica-Oblique     7. Helvetica-BoldOblique 8. Courier
   9.  Courier-Bold         10. Courier-Oblique      11. Courier-BoldOblique
  12.  Symbol

The size of the font is given by parameter size (fiducial coordinates).
Note that the old Fortran equivalent subroutine identified fonts by 1-origin
index (C index = Fortran index -1).  */

#define NUM_LW_FONTS 13

typedef struct font_entry font_entry;
  
struct font_entry{           /* For each font allocated, code and size */
  int code;
  int ifsz;
  font_entry *chain;
};

static font_entry *chain_bgn=NULL;
static font_entry *chain_end=NULL;

void SetFont(int code,double size)
{
  int ifsz,i;

  static char *font_names[NUM_LW_FONTS]={
    "Times-Roman","Times-Bold","Times-Italic","Times-BoldItalic",
    "Helvetica","Helvetica-Bold","Helvetica-Oblique","Helvetica-BoldOblique",
    "Courier","Courier-Bold","Courier-Oblique","Courier-BoldOblique",
    "Symbol"};


  font_entry *fep;
  static char function_name[]="SetFont";

  /*-------------End Declarations---------------------------------*/

  if(code<0 || code>=NUM_LW_FONTS){
    fprintf(stderr,"Invalid code in function SetFont\n");
    exit(1);
  }

  ifsz=nint(size*G.fidconvp);
  ifsz=MAX(1,ifsz);

  /* First see if font has been defined yet.  If so, invoke it by its
  name, fontnnn, where nnn is the sequence number in the chain.
  Otherwise, define a new font, and add a new font_entry to the
  chain. */

  for(i=0,fep=chain_bgn;fep!=NULL;fep=fep->chain,++i){
    if(fep->code==code && fep->ifsz==ifsz)break;
  }

  if(fep==NULL){
    if((fep=(font_entry*)malloc(sizeof(font_entry)))==NULL){
      fprintf(stderr,"Insufficient memory in %s()\n",function_name);
      return;
    }
    if(chain_bgn==NULL){
      chain_bgn=fep;
      chain_end=fep;
    }
    else{
      chain_end->chain=fep;
      chain_end=fep;
    }
    fep->ifsz=ifsz;
    fep->code=code;
    fep->chain=NULL;

    fprintf(G.psfile,"/font%d /%s findfont %d scalefont def\n",
	    i,font_names[code],ifsz);
  }
  fprintf(G.psfile,"font%d setfont\n",i); 

  G.icurfnt=code;
  G.ifontsz=ifsz;
}

/* This function frees the font structures allocates and resets the
   pointers. */

void ResetFont()
{
  font_entry *fep,*newfep;
  
  for(fep=chain_bgn;fep!=NULL;fep=newfep){
    newfep=fep->chain;
    free(fep);
  }
  chain_bgn=NULL;
  chain_end=NULL;
}
