#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>

#include "GraphicsCom.c"
#include "Graf.h"
#include "grafprot.h"

/* This subroutine defines a 'window area' relative to the fiducial
coordinate system.  The window area defined by this subroutine is the
area which is outlined by the frame in any later call to the frame
subroutine, although it is not necessary to call the frame subroutine.
The window area is also used by the subroutines curve and contour to
`clip' any lines or curves which might go outside its boundaries.  You
can have several windows per page, but they must be dealt with one at
at time (before the endpage call).

This subroutine also establishes the translation between the fiducial
coordinates (and therefore ultimately positions on the page) and the
coordinates supplied by the user.  This translation can be either
linear or logarithmic, on either x or y axes.

Here are the meanings of the parameters....

xmin,xmax are the x dimensions of the window in fiducial
            coordinates
ymin,ymax are the y dimensions of the window in fiducial
            coordinates.
ixcode=0    means use linear scale in the x direction.
ixcode=1    means use log scale in the x direction.
iycode=0    means use linear scale in the y direction
iycode=1    means use log scale in the y direction.
uxleft,uxright are the x coordinates of the left and right sides of
            the window in user coordinates.
uybott,uytop are the y coordinates of the bottom and top of the
            window in user coordinates.

It is allowed to have uxleft .gt. uxright, or uybott .gt. uytop, if
you want scale running backwards.  However, must always have xmin
.lt. xmax and ymin .lt. ymax.  */

void SetWindow(double xmin,double xmax,double ymin,double ymax,
               int ixcode,double uxleft,double uxright,
	       int iycode,double uybott,double uytop)
{
  static char function_name[]="SetWindow";

  /* Check for errors in parameters. */

  if(ixcode<0 || ixcode>1 || iycode<0 || iycode>1 || 
     xmin==xmax || ymin==ymax || uxleft==uxright || uybott==uytop){
    fprintf(stderr,"Invalid parameter in %s()\n",function_name);
    return;
  }
  
  if((ixcode==1 && (uxleft<=0.0 || uxright<=0.0)) ||
     (iycode==1 && (uybott<=0.0 || uytop<=0.0))){
    fprintf(stderr,"Invalid parameter in %s()\n",function_name);
    return;
  }

  /* Set up common. xwind,ywind are the coordinates of the lower left
     corner of the window in inches.  dxwind,dywind are the x,y
     dimensions of the window in inches. */

  G.ixlinlog=ixcode;
  G.iylinlog=iycode;
  G.xwind=G.xfid+xmin*G.fidconvi;
  G.ywind=G.yfid+ymin*G.fidconvi;
  G.dxwind=(xmax-xmin)*G.fidconvi;
  G.dywind=(ymax-ymin)*G.fidconvi;

  /* In a linear scale, xuser=xleft and dxuser is width of window in
     user coordinates.  In a log scale, xuser=log(xleft) and dxuser is
     window width in log units.  In either case, note that dxuser may
     be neg.  Similarly for y scale. */

  if(G.ixlinlog==0){
    G.xuser=uxleft;
    G.dxuser=uxright-uxleft;
  }
  else{
    G.xuser=log10(uxleft);
    G.dxuser=log10(uxright/uxleft);
  }

  if(G.iylinlog==0){
    G.yuser=uybott;
    G.dyuser=uytop-uybott;
  }
  else{
    G.yuser=log10(uybott);
    G.dyuser=log10(uytop/uybott);
  }
}
