#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "wallprot.h"
#include "grafprot.h"

/* Test leapfrog integrator, and single bounce off wall. */

static void printit(double t, double x, double y, double px, double py);
static void frameit(int iframe,double x,double y);

static double a,A,right,top;

int main()
{
  int n,i,nframes,iframe;
  double x0,px0,x1,tau,t;
  double y0,py0,y1,theta0;

  a=0.005;
  A=200.0;
  tau=0.00025;
  t=0.0;
  n=32;
  nframes=3000;
  right=1.0;
  top=sqrt(2.0);
  theta0=32.0;

  theta0=M_PI*theta0/180.0;
  x0=0.05;
  y0=0.05;
  px0=cos(theta0);
  py0=sin(theta0);
  frameit(0,x0,y0);

  for(iframe=1;iframe<=nframes;++iframe){
    for(i=0;i<n;++i){
      x1=x0+0.5*tau*px0;
      y1=y0+0.5*tau*py0;

      px0=px0+tau*A*(-wf0(-x1/a)+wf0((x1-right)/a));
      py0=py0+tau*A*(-wf0(-y1/a)+wf0((y1-top)/a));

      x0=x1+0.5*tau*px0;
      y0=y1+0.5*tau*py0;

      t=t+tau;
    }
    frameit(iframe,x0,y0);
  }
  printit(t,x0,y0,px0,py0);
  exit(0);
}

static void printit(double t, double x, double y, double px, double py)
{
  double E;

  E=0.5*(px*px+py*py)+A*a*(wv0(-x/a)+wv0((x-right)/a)
		 +wv0(-y/a)+wv0((y-top)/a));

  printf("%10.5f %10.5f %10.5f %10.5f %10.5f %10.5f\n",t,x,y,px,py,E);
}

static void frameit(int iframe,double x,double y)
{
  static char filename[20];
  static CurvePoint walls[5];

  sprintf(filename,"frames/%04d.ps",iframe);
  SetGraphicsFileName(filename);
  if(OpenGraphics()==1){
    printf("Can't open graphics file %d\n",iframe);
    exit(1);
  }
  NewPage(0);
  SetFiducial(1.25,1.0,6.0);
  SetWindow(0.0,right,0.0,top, 0,0.0,right, 0,0.0,top);
  SetBezier(0);

  walls[0].x=0.0;
  walls[0].y=0.0;
  walls[1].x=right;
  walls[1].y=0.0;
  walls[2].x=right;
  walls[2].y=top;
  walls[3].x=0.0;
  walls[3].y=top;
  walls[4]=walls[0];

  DrawCurve2(walls,5,True,True,True,True,False);
  DrawBullet(x,y,0.005);
  EndPage();
  CloseGraphics();
}
