#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "wallprot.h"

/* This is version 1 of the interparticle potential.  It is repulsive
   at short distances, and attractive at larger.   Parameter x is the
   distance between the particles, in dimensionless form.  It is
   assumed to be >= 0.

   Static parameter b is the dimensionless distance to the attractive
   well, and B is the strength of the attractive well (it is
   attractive for negative B).

   The potential is 

      V(x) = exp(-x^2) + B*(exp(-(x-b)^2) + exp(-(x+b)^2))

*/

static double sinhd(double x);

static double b,B,Bbfac,twob,Bbfac1;

/* Initialize parameters of interparticle potential.  */

void init_ppot1()
{
  b=2.0;
  B=-1.0;

  twob=2.0*b;
  Bbfac=2.0*B*exp(-b*b);
  Bbfac1=4.0*b*b*Bbfac;
}

/* The potential energy V(x). */

double pv1(double x)
{

  if(x>7.6)return(0.0);
  return(exp(-x*x)*(1.0+Bbfac*cosh(twob*x)));
}

/* The quantity V'(x)/x, which is needed for the force functions (with
   x interpreted as r/a).  */

double pv1deriv(double x)
{
  double x1;

  if(x>7.6)return(0.0);
  x1=twob*x;
  return(exp(-x*x)*(-2.0*(1.0+Bbfac*cosh(x1)))
	 +Bbfac1*sinhd(x1));
}

/* Computes the function sinh(x)/x.  This function relies on the
   assumption that the library function sinh() has a *relative*
   precision close to machine precision, even when x is small (not
   just an *absolute* precision).  If this were not true, we'd have to
   use Taylor series for |x| less than about 1.  */

static double sinhd(double x)
{
  if(fabs(x)<2.0e-9)return(1.0);
  else return(sinh(x)/x);
}
  

  
  
