#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "wallprot.h"
#include "grafprot.h"

typedef struct particle particle;
struct particle{
  double x;
  double y;
  double px;
  double py;
};

#define Nparts 600   /* Number of particles */

static void print_energy(double t, particle parts[], int nparts);
static void frameit(int iframe,particle parts[], int nparts);

static double a,asq,A,B,right,top;

int main()
{
  int n,i,nframes,iframe,istep,j;
  double tau,t,kT,vx,vy,rootkT;
  static particle parts[Nparts],parts1[Nparts];
  double x1,y1,dx,dy,drsq,dfx,dfy,xpnt,fx,fy;
  double px,py;

  a=0.005;
  asq=a*a;
  A=200.0;
  B=2.0;
  kT=0.5;
  rootkT=sqrt(kT);
  tau=0.00025;
  t=0.0;
  n=32;
  nframes=3000;
  right=1.0;
  top=sqrt(2.0);

  for(i=0;i<Nparts;++i){
    parts[i].x=right*urand();
    parts[i].y=top*urand();
    gaurand(&vx,&vy);
    parts[i].px=rootkT*vx;
    parts[i].py=rootkT*vy;
  }

  /* Print initial conditions */

  for(i=0;i<Nparts;++i)
    printf("%d %10.4f %10.4f %10.4f %10.4f\n",
	   i,parts[i].x,parts[i].y,parts[i].px,parts[i].py);

  frameit(0,parts,Nparts);

  for(iframe=1;iframe<=nframes;++iframe){
    for(istep=0;istep<n;++istep){
      for(i=0;i<Nparts;++i){
	parts1[i].x=parts[i].x+0.5*tau*parts[i].px;
	parts1[i].y=parts[i].y+0.5*tau*parts[i].py;
      }
      for(i=0;i<Nparts;++i){
	x1=parts1[i].x;
	y1=parts1[i].y;

	fx=A*(-wf0(-x1/a)+wf0((x1-right)/a));
	fy=A*(-wf0(-y1/a)+wf0((y1-top)/a));

	dfx=0.0;
	dfy=0.0;

	for(j=0;j<Nparts;++j){
	  if(j==i)continue;
	  dx=x1-parts1[j].x;
	  dy=y1-parts1[j].y;
	  drsq=dx*dx+dy*dy;
	  xpnt=drsq/asq;
	  if(xpnt>36.8)continue;
	  xpnt=exp(-xpnt);
	  dfx+=dx*xpnt;
	  dfy+=dy*xpnt;
	}
	fx+=2.0*B*dfx/asq;
	fy+=2.0*B*dfy/asq;
	  
	parts1[i].px=parts[i].px+tau*fx;
	parts1[i].py=parts[i].py+tau*fy;
      }
      for(i=0;i<Nparts;++i){
	parts1[i].x+=0.5*tau*parts1[i].px;
	parts1[i].y+=0.5*tau*parts1[i].py;
      }
      for(i=0;i<Nparts;++i)parts[i]=parts1[i];
    }
    t=t+n*tau;
    frameit(iframe,parts,Nparts);
    print_energy(t,parts,Nparts);
  }
  exit(0);
}

static void print_energy(double t, particle parts[], int nparts)
{
  double E,px,py,x,y,xpnt,dx,dy;
  int i,j;

  E=0.0;
  for(i=0;i<nparts;++i){
    px=parts[i].px;
    py=parts[i].py;
    E+=0.5*(px*px+py*py);
    x=parts[i].x;
    y=parts[i].y;
    E+=A*a*(wv0(-x/a)+wv0((x-right)/a)+wv0(-y/a)+wv0((y-top)/a));
    for(j=0;j<i;++j){
      dx=x-parts[j].x;
      dy=y-parts[j].y;
      xpnt=(dx*dx+dy*dy)/asq;
      if(xpnt>36.8)continue;
      E+=B*exp(-xpnt);
    }
  }

  printf("%10.5f %10.5f\n",t,E);
}

static void frameit(int iframe,particle parts[], int nparts)
{
  static char filename[20];
  static CurvePoint walls[5];
  int i;

  sprintf(filename,"frames/%04d.ps",iframe);
  SetGraphicsFileName(filename);
  if(OpenGraphics()==1){
    printf("Can't open graphics file %d\n",iframe);
    exit(1);
  }
  NewPage(0);
  SetFiducial(1.25,1.0,6.0);
  SetWindow(0.0,right,0.0,top, 0,0.0,right, 0,0.0,top);
  SetBezier(0);

  walls[0].x=0.0;
  walls[0].y=0.0;
  walls[1].x=right;
  walls[1].y=0.0;
  walls[2].x=right;
  walls[2].y=top;
  walls[3].x=0.0;
  walls[3].y=top;
  walls[4]=walls[0];

  DrawCurve2(walls,5,True,True,True,True,False);
  for(i=0;i<nparts;++i){
    DrawBullet(parts[i].x,parts[i].y,0.005);
  }
  EndPage();
  CloseGraphics();
}
