#include <stdio.h>
#include <math.h>
#include "wallprot.h"

/* Basic wall potential function.

   wv0(x) = (1/2)log(1+exp(2x)) = (1/2)(2x + log(1+exp(-2x)))

*/

double wv0(double x)
{
  double y,z;
  double ysq,sum,den,pwr,term;

  if(x<=0.0){
    if(x<-345.0)return(0.0);
    z=exp(2.0*x);
    if(x<-1.15){
      y=z/(2.0+z);
      if(x<-8.86)return(y);
      ysq=y*y;
      sum=1.0;
      den=1.0;
      pwr=1.0;
      do{
	pwr=pwr*ysq;
	den=den+2.0;
	term=pwr/den;
	sum=sum+term;
      }while(term>1.0e-16);
      return(y*sum);
    }
    return(0.5*(log(1.0+z)));
  }

  else{     /* x>0.0 */
    if(x>18.42)return(x);
    return(x+0.5*log(1.0+exp(-2.0*x)));
  }
}
